==> jenkins-core-1.642.3-sources.jar: hudson/tools/Messages.java <==
// CHECKSTYLE:OFF

package hudson.tools;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code CommandInstaller.DescriptorImpl.displayName}: {@code Run
     * Shell Command}.
     * 
     * @return
     *     {@code Run Shell Command}
     */
    public static String CommandInstaller_DescriptorImpl_displayName() {
        return holder.format("CommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code CommandInstaller.DescriptorImpl.displayName}: {@code Run
     * Shell Command}.
     * 
     * @return
     *     {@code Run Shell Command}
     */
    public static Localizable _CommandInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "CommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code ZipExtractionInstaller.could_not_connect}: {@code Could not
     * connect to URL.}.
     * 
     * @return
     *     {@code Could not connect to URL.}
     */
    public static String ZipExtractionInstaller_could_not_connect() {
        return holder.format("ZipExtractionInstaller.could_not_connect");
    }

    /**
     * Key {@code ZipExtractionInstaller.could_not_connect}: {@code Could not
     * connect to URL.}.
     * 
     * @return
     *     {@code Could not connect to URL.}
     */
    public static Localizable _ZipExtractionInstaller_could_not_connect() {
        return new Localizable(holder, "ZipExtractionInstaller.could_not_connect");
    }

    /**
     * Key {@code CommandInstaller.no_command}: {@code Must provide a command
     * to run.}.
     * 
     * @return
     *     {@code Must provide a command to run.}
     */
    public static String CommandInstaller_no_command() {
        return holder.format("CommandInstaller.no_command");
    }

    /**
     * Key {@code CommandInstaller.no_command}: {@code Must provide a command
     * to run.}.
     * 
     * @return
     *     {@code Must provide a command to run.}
     */
    public static Localizable _CommandInstaller_no_command() {
        return new Localizable(holder, "CommandInstaller.no_command");
    }

    /**
     * Key {@code ToolDescriptor.NotADirectory}: {@code {0} is not a
     * directory on the Jenkins master (but perhaps it exists on some
     * slaves)}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code {0} is not a directory on the Jenkins master (but perhaps it
     *     exists on some slaves)}
     */
    public static String ToolDescriptor_NotADirectory(Object arg0) {
        return holder.format("ToolDescriptor.NotADirectory", arg0);
    }

    /**
     * Key {@code ToolDescriptor.NotADirectory}: {@code {0} is not a
     * directory on the Jenkins master (but perhaps it exists on some
     * slaves)}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code {0} is not a directory on the Jenkins master (but perhaps it
     *     exists on some slaves)}
     */
    public static Localizable _ToolDescriptor_NotADirectory(Object arg0) {
        return new Localizable(holder, "ToolDescriptor.NotADirectory", arg0);
    }

    /**
     * Key {@code CommandInstaller.no_toolHome}: {@code Must provide a tool
     * home directory.}.
     * 
     * @return
     *     {@code Must provide a tool home directory.}
     */
    public static String CommandInstaller_no_toolHome() {
        return holder.format("CommandInstaller.no_toolHome");
    }

    /**
     * Key {@code CommandInstaller.no_toolHome}: {@code Must provide a tool
     * home directory.}.
     * 
     * @return
     *     {@code Must provide a tool home directory.}
     */
    public static Localizable _CommandInstaller_no_toolHome() {
        return new Localizable(holder, "CommandInstaller.no_toolHome");
    }

    /**
     * Key {@code JDKInstaller.RequireOracleAccount}: {@code Installing JDK
     * requires Oracle account. <a href="{0}" target="_new">Please enter your
     * username/password</a>}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Installing JDK requires Oracle account. <a href="{0}"
     *     target="_new">Please enter your username/password</a>}
     */
    public static String JDKInstaller_RequireOracleAccount(Object arg0) {
        return holder.format("JDKInstaller.RequireOracleAccount", arg0);
    }

    /**
     * Key {@code JDKInstaller.RequireOracleAccount}: {@code Installing JDK
     * requires Oracle account. <a href="{0}" target="_new">Please enter your
     * username/password</a>}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Installing JDK requires Oracle account. <a href="{0}"
     *     target="_new">Please enter your username/password</a>}
     */
    public static Localizable _JDKInstaller_RequireOracleAccount(Object arg0) {
        return new Localizable(holder, "JDKInstaller.RequireOracleAccount", arg0);
    }

    /**
     * Key {@code InstallSourceProperty.DescriptorImpl.displayName}: {@code
     * Install automatically}.
     * 
     * @return
     *     {@code Install automatically}
     */
    public static String InstallSourceProperty_DescriptorImpl_displayName() {
        return holder.format("InstallSourceProperty.DescriptorImpl.displayName");
    }

    /**
     * Key {@code InstallSourceProperty.DescriptorImpl.displayName}: {@code
     * Install automatically}.
     * 
     * @return
     *     {@code Install automatically}
     */
    public static Localizable _InstallSourceProperty_DescriptorImpl_displayName() {
        return new Localizable(holder, "InstallSourceProperty.DescriptorImpl.displayName");
    }

    /**
     * Key {@code JDKInstaller.UnableToInstallUntilLicenseAccepted}: {@code
     * Unable to auto-install JDK until the license is accepted.}.
     * 
     * @return
     *     {@code Unable to auto-install JDK until the license is accepted.}
     */
    public static String JDKInstaller_UnableToInstallUntilLicenseAccepted() {
        return holder.format("JDKInstaller.UnableToInstallUntilLicenseAccepted");
    }

    /**
     * Key {@code JDKInstaller.UnableToInstallUntilLicenseAccepted}: {@code
     * Unable to auto-install JDK until the license is accepted.}.
     * 
     * @return
     *     {@code Unable to auto-install JDK until the license is accepted.}
     */
    public static Localizable _JDKInstaller_UnableToInstallUntilLicenseAccepted() {
        return new Localizable(holder, "JDKInstaller.UnableToInstallUntilLicenseAccepted");
    }

    /**
     * Key {@code ToolLocationNodeProperty.displayName}: {@code Tool
     * Locations}.
     * 
     * @return
     *     {@code Tool Locations}
     */
    public static String ToolLocationNodeProperty_displayName() {
        return holder.format("ToolLocationNodeProperty.displayName");
    }

    /**
     * Key {@code ToolLocationNodeProperty.displayName}: {@code Tool
     * Locations}.
     * 
     * @return
     *     {@code Tool Locations}
     */
    public static Localizable _ToolLocationNodeProperty_displayName() {
        return new Localizable(holder, "ToolLocationNodeProperty.displayName");
    }

    /**
     * Key {@code ZipExtractionInstaller.malformed_url}: {@code Malformed
     * URL.}.
     * 
     * @return
     *     {@code Malformed URL.}
     */
    public static String ZipExtractionInstaller_malformed_url() {
        return holder.format("ZipExtractionInstaller.malformed_url");
    }

    /**
     * Key {@code ZipExtractionInstaller.malformed_url}: {@code Malformed
     * URL.}.
     * 
     * @return
     *     {@code Malformed URL.}
     */
    public static Localizable _ZipExtractionInstaller_malformed_url() {
        return new Localizable(holder, "ZipExtractionInstaller.malformed_url");
    }

    /**
     * Key {@code JDKInstaller.DescriptorImpl.doCheckId}: {@code Define JDK
     * ID}.
     * 
     * @return
     *     {@code Define JDK ID}
     */
    public static String JDKInstaller_DescriptorImpl_doCheckId() {
        return holder.format("JDKInstaller.DescriptorImpl.doCheckId");
    }

    /**
     * Key {@code JDKInstaller.DescriptorImpl.doCheckId}: {@code Define JDK
     * ID}.
     * 
     * @return
     *     {@code Define JDK ID}
     */
    public static Localizable _JDKInstaller_DescriptorImpl_doCheckId() {
        return new Localizable(holder, "JDKInstaller.DescriptorImpl.doCheckId");
    }

    /**
     * Key {@code ZipExtractionInstaller.DescriptorImpl.displayName}: {@code
     * Extract *.zip/*.tar.gz}.
     * 
     * @return
     *     {@code Extract *.zip/*.tar.gz}
     */
    public static String ZipExtractionInstaller_DescriptorImpl_displayName() {
        return holder.format("ZipExtractionInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code ZipExtractionInstaller.DescriptorImpl.displayName}: {@code
     * Extract *.zip/*.tar.gz}.
     * 
     * @return
     *     {@code Extract *.zip/*.tar.gz}
     */
    public static Localizable _ZipExtractionInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "ZipExtractionInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code JDKInstaller.FailedToInstallJDK}: {@code Failed to install
     * JDK. Exit code={0}}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Failed to install JDK. Exit code={0}}
     */
    public static String JDKInstaller_FailedToInstallJDK(Object arg0) {
        return holder.format("JDKInstaller.FailedToInstallJDK", arg0);
    }

    /**
     * Key {@code JDKInstaller.FailedToInstallJDK}: {@code Failed to install
     * JDK. Exit code={0}}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Failed to install JDK. Exit code={0}}
     */
    public static Localizable _JDKInstaller_FailedToInstallJDK(Object arg0) {
        return new Localizable(holder, "JDKInstaller.FailedToInstallJDK", arg0);
    }

    /**
     * Key {@code ZipExtractionInstaller.bad_connection}: {@code Server
     * rejected connection.}.
     * 
     * @return
     *     {@code Server rejected connection.}
     */
    public static String ZipExtractionInstaller_bad_connection() {
        return holder.format("ZipExtractionInstaller.bad_connection");
    }

    /**
     * Key {@code ZipExtractionInstaller.bad_connection}: {@code Server
     * rejected connection.}.
     * 
     * @return
     *     {@code Server rejected connection.}
     */
    public static Localizable _ZipExtractionInstaller_bad_connection() {
        return new Localizable(holder, "ZipExtractionInstaller.bad_connection");
    }

    /**
     * Key {@code JDKInstaller.DescriptorImpl.doCheckAcceptLicense}: {@code
     * You must agree to the license to download the JDK.}.
     * 
     * @return
     *     {@code You must agree to the license to download the JDK.}
     */
    public static String JDKInstaller_DescriptorImpl_doCheckAcceptLicense() {
        return holder.format("JDKInstaller.DescriptorImpl.doCheckAcceptLicense");
    }

    /**
     * Key {@code JDKInstaller.DescriptorImpl.doCheckAcceptLicense}: {@code
     * You must agree to the license to download the JDK.}.
     * 
     * @return
     *     {@code You must agree to the license to download the JDK.}
     */
    public static Localizable _JDKInstaller_DescriptorImpl_doCheckAcceptLicense() {
        return new Localizable(holder, "JDKInstaller.DescriptorImpl.doCheckAcceptLicense");
    }

    /**
     * Key {@code BatchCommandInstaller.DescriptorImpl.displayName}: {@code
     * Run Batch Command}.
     * 
     * @return
     *     {@code Run Batch Command}
     */
    public static String BatchCommandInstaller_DescriptorImpl_displayName() {
        return holder.format("BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code BatchCommandInstaller.DescriptorImpl.displayName}: {@code
     * Run Batch Command}.
     * 
     * @return
     *     {@code Run Batch Command}
     */
    public static Localizable _BatchCommandInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code JDKInstaller.DescriptorImpl.displayName}: {@code Install
     * from java.sun.com}.
     * 
     * @return
     *     {@code Install from java.sun.com}
     */
    public static String JDKInstaller_DescriptorImpl_displayName() {
        return holder.format("JDKInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code JDKInstaller.DescriptorImpl.displayName}: {@code Install
     * from java.sun.com}.
     * 
     * @return
     *     {@code Install from java.sun.com}
     */
    public static Localizable _JDKInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "JDKInstaller.DescriptorImpl.displayName");
    }

}

==> jenkins-core-2.414.1-sources.jar: hudson/tools/Messages.java <==
// CHECKSTYLE:OFF

package hudson.tools;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ZipExtractionInstaller.malformed_url}: {@code Malformed
     * URL.}.
     * 
     * @return
     *     {@code Malformed URL.}
     */
    public static String ZipExtractionInstaller_malformed_url() {
        return holder.format("ZipExtractionInstaller.malformed_url");
    }

    /**
     * Key {@code ZipExtractionInstaller.malformed_url}: {@code Malformed
     * URL.}.
     * 
     * @return
     *     {@code Malformed URL.}
     */
    public static Localizable _ZipExtractionInstaller_malformed_url() {
        return new Localizable(holder, "ZipExtractionInstaller.malformed_url");
    }

    /**
     * Key {@code ToolLocationNodeProperty.displayName}: {@code Tool
     * Locations}.
     * 
     * @return
     *     {@code Tool Locations}
     */
    public static String ToolLocationNodeProperty_displayName() {
        return holder.format("ToolLocationNodeProperty.displayName");
    }

    /**
     * Key {@code ToolLocationNodeProperty.displayName}: {@code Tool
     * Locations}.
     * 
     * @return
     *     {@code Tool Locations}
     */
    public static Localizable _ToolLocationNodeProperty_displayName() {
        return new Localizable(holder, "ToolLocationNodeProperty.displayName");
    }

    /**
     * Key {@code CommandInstaller.DescriptorImpl.displayName}: {@code Run
     * Shell Command}.
     * 
     * @return
     *     {@code Run Shell Command}
     */
    public static String CommandInstaller_DescriptorImpl_displayName() {
        return holder.format("CommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code CommandInstaller.DescriptorImpl.displayName}: {@code Run
     * Shell Command}.
     * 
     * @return
     *     {@code Run Shell Command}
     */
    public static Localizable _CommandInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "CommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code CannotBeInstalled}: {@code Installer "{0}" cannot be used
     * to install "{1}" on the node "{2}"}.
     * 
     * @param arg2
     *      3rd format parameter, {@code {2}}, as {@link String#valueOf(Object)}.
     * @param arg1
     *      2nd format parameter, {@code {1}}, as {@link String#valueOf(Object)}.
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Installer "{0}" cannot be used to install "{1}" on the node
     *     "{2}"}
     */
    public static String CannotBeInstalled(Object arg0, Object arg1, Object arg2) {
        return holder.format("CannotBeInstalled", arg0, arg1, arg2);
    }

    /**
     * Key {@code CannotBeInstalled}: {@code Installer "{0}" cannot be used
     * to install "{1}" on the node "{2}"}.
     * 
     * @param arg2
     *      3rd format parameter, {@code {2}}, as {@link String#valueOf(Object)}.
     * @param arg1
     *      2nd format parameter, {@code {1}}, as {@link String#valueOf(Object)}.
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code Installer "{0}" cannot be used to install "{1}" on the node
     *     "{2}"}
     */
    public static Localizable _CannotBeInstalled(Object arg0, Object arg1, Object arg2) {
        return new Localizable(holder, "CannotBeInstalled", arg0, arg1, arg2);
    }

    /**
     * Key {@code CommandInstaller.no_command}: {@code Must provide a command
     * to run.}.
     * 
     * @return
     *     {@code Must provide a command to run.}
     */
    public static String CommandInstaller_no_command() {
        return holder.format("CommandInstaller.no_command");
    }

    /**
     * Key {@code CommandInstaller.no_command}: {@code Must provide a command
     * to run.}.
     * 
     * @return
     *     {@code Must provide a command to run.}
     */
    public static Localizable _CommandInstaller_no_command() {
        return new Localizable(holder, "CommandInstaller.no_command");
    }

    /**
     * Key {@code ZipExtractionInstaller.DescriptorImpl.displayName}: {@code
     * Extract *.zip/*.tar.gz}.
     * 
     * @return
     *     {@code Extract *.zip/*.tar.gz}
     */
    public static String ZipExtractionInstaller_DescriptorImpl_displayName() {
        return holder.format("ZipExtractionInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code ZipExtractionInstaller.DescriptorImpl.displayName}: {@code
     * Extract *.zip/*.tar.gz}.
     * 
     * @return
     *     {@code Extract *.zip/*.tar.gz}
     */
    public static Localizable _ZipExtractionInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "ZipExtractionInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code InstallSourceProperty.DescriptorImpl.displayName}: {@code
     * Install automatically}.
     * 
     * @return
     *     {@code Install automatically}
     */
    public static String InstallSourceProperty_DescriptorImpl_displayName() {
        return holder.format("InstallSourceProperty.DescriptorImpl.displayName");
    }

    /**
     * Key {@code InstallSourceProperty.DescriptorImpl.displayName}: {@code
     * Install automatically}.
     * 
     * @return
     *     {@code Install automatically}
     */
    public static Localizable _InstallSourceProperty_DescriptorImpl_displayName() {
        return new Localizable(holder, "InstallSourceProperty.DescriptorImpl.displayName");
    }

    /**
     * Key {@code CommandInstaller.no_toolHome}: {@code Must provide a tool
     * home directory.}.
     * 
     * @return
     *     {@code Must provide a tool home directory.}
     */
    public static String CommandInstaller_no_toolHome() {
        return holder.format("CommandInstaller.no_toolHome");
    }

    /**
     * Key {@code CommandInstaller.no_toolHome}: {@code Must provide a tool
     * home directory.}.
     * 
     * @return
     *     {@code Must provide a tool home directory.}
     */
    public static Localizable _CommandInstaller_no_toolHome() {
        return new Localizable(holder, "CommandInstaller.no_toolHome");
    }

    /**
     * Key {@code BatchCommandInstaller.DescriptorImpl.displayName}: {@code
     * Run Batch Command}.
     * 
     * @return
     *     {@code Run Batch Command}
     */
    public static String BatchCommandInstaller_DescriptorImpl_displayName() {
        return holder.format("BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code BatchCommandInstaller.DescriptorImpl.displayName}: {@code
     * Run Batch Command}.
     * 
     * @return
     *     {@code Run Batch Command}
     */
    public static Localizable _BatchCommandInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Key {@code ZipExtractionInstaller.bad_connection}: {@code Server
     * rejected connection.}.
     * 
     * @return
     *     {@code Server rejected connection.}
     */
    public static String ZipExtractionInstaller_bad_connection() {
        return holder.format("ZipExtractionInstaller.bad_connection");
    }

    /**
     * Key {@code ZipExtractionInstaller.bad_connection}: {@code Server
     * rejected connection.}.
     * 
     * @return
     *     {@code Server rejected connection.}
     */
    public static Localizable _ZipExtractionInstaller_bad_connection() {
        return new Localizable(holder, "ZipExtractionInstaller.bad_connection");
    }

    /**
     * Key {@code ZipExtractionInstaller.could_not_connect}: {@code Could not
     * connect to URL.}.
     * 
     * @return
     *     {@code Could not connect to URL.}
     */
    public static String ZipExtractionInstaller_could_not_connect() {
        return holder.format("ZipExtractionInstaller.could_not_connect");
    }

    /**
     * Key {@code ZipExtractionInstaller.could_not_connect}: {@code Could not
     * connect to URL.}.
     * 
     * @return
     *     {@code Could not connect to URL.}
     */
    public static Localizable _ZipExtractionInstaller_could_not_connect() {
        return new Localizable(holder, "ZipExtractionInstaller.could_not_connect");
    }

    /**
     * Key {@code ToolDescriptor.NotADirectory}: {@code {0} is not a
     * directory on the Jenkins controller (but perhaps it exists on some
     * agents)}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code {0} is not a directory on the Jenkins controller (but perhaps
     *     it exists on some agents)}
     */
    public static String ToolDescriptor_NotADirectory(Object arg0) {
        return holder.format("ToolDescriptor.NotADirectory", arg0);
    }

    /**
     * Key {@code ToolDescriptor.NotADirectory}: {@code {0} is not a
     * directory on the Jenkins controller (but perhaps it exists on some
     * agents)}.
     * 
     * @param arg0
     *      1st format parameter, {@code {0}}, as {@link String#valueOf(Object)}.
     * @return
     *     {@code {0} is not a directory on the Jenkins controller (but perhaps
     *     it exists on some agents)}
     */
    public static Localizable _ToolDescriptor_NotADirectory(Object arg0) {
        return new Localizable(holder, "ToolDescriptor.NotADirectory", arg0);
    }

}
